__all__ = [
    "__author__",
    "__copyright__",
    "__email__",
    "__license__",
    "__summary__",
    "__title__",
    "__uri__",
    "__version__",
]

__title__ = "overpy"
__summary__ = "Python Wrapper to access the OpenStreepMap Overpass API"
__uri__ = "https://github.com/DinoTools/python-overpy"

__version__ = "0.2.0"

__author__ = "PhiBo (DinoTools)"
__email__ = ""

__license__ = "MIT"
__copyright__ = "Copyright 2014 %s" % __author__
